@@ -1,19 +1,19 @@
 package AFS::KTC_EKEY;
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)KTC_EKEY.pm,v 2.0 2002/07/02 06:12:59 nog Exp"
+# RCS-Id: "@(#)$Id: KTC_EKEY.pm 528 2004-01-06 18:36:03Z nog $"
 #
-# Copyright  2001-2002 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
+# Copyright  2001-2004 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 #------------------------------------------------------------------------------
 
-use AFS;
+use AFS ();
 
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(AFS);
-$VERSION = sprintf("%d.%02d", q/2.0/ =~ /(\d+)\.(\d+)/);
+$VERSION = do{my@r=q/Major Version 2.2 $Rev: 528 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
 
 sub UserReadPassword {
     my $class = shift;
@@ -44,5 +44,4 @@ sub des_string_to_key {
 #     char data[8];
 # };
 
-
 1;
