@@ -1,19 +1,19 @@
 package AFS::KTC_TOKEN;
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)KTC_TOKEN.pm,v 2.0 2002/07/02 06:13:26 nog Exp"
+# RCS-Id: "@(#)$Id: KTC_TOKEN.pm 528 2004-01-06 18:36:03Z nog $"
 #
-# Copyright  2001-2002 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
+# Copyright  2001-2004 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 #------------------------------------------------------------------------------
 
-use AFS;
+use AFS ();
 
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(AFS);
-$VERSION = sprintf("%d.%02d", q/2.0/ =~ /(\d+)\.(\d+)/);
+$VERSION = do{my@r=q/Major Version 2.2 $Rev: 528 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
 
 sub nulltoken {
     my $class  = shift;
@@ -45,6 +45,12 @@ sub GetToken {
     AFS::ktc_GetToken(@_);
 }
 
+sub FromString {
+    my $class  = shift;
+
+    AFS::ktc_FromString(@_);
+}
+
 sub SetToken {
     my $class  = shift;
 
