@@ -1,6 +1,6 @@
 package AFS::VOS;
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)$Id: VOS.pm 587 2004-03-07 15:30:38Z nog $"
+# RCS-Id: "@(#)$Id: VOS.pm 625 2004-05-05 13:30:16Z nog $"
 #
 # Copyright  2003-2004 Alf Wachsmann <alfw@slac.stanford.edu> and
 #                       Norbert E. Gruener <nog@MPA-Garching.MPG.de>
@@ -14,12 +14,12 @@ use AFS ();
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(AFS);
-$VERSION = do{my@r=q/Major Version 2.2 $Rev: 587 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
+$VERSION = do{my@r=q/Major Version 2.2 $Rev: 625 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
 
 sub DESTROY {
     my (undef, undef, undef, $subroutine) = caller(1);
-    if ($subroutine !~ /eval/) { undef $_[0]; }    # self->DESTROY
-    else { AFS::VOS::_DESTROY($_[0]); }            # undef self
+    if (! defined $subroutine or $subroutine !~ /eval/) { undef $_[0]; }  # self->DESTROY
+    else { AFS::VOS::_DESTROY($_[0]); }                                   # undef self
 }
 
 sub setquota {
